@@ -27,7 +27,7 @@ import os.path
 import googletrans
 from colored import fore, style
 from googletrans import Translator
-from __metadata__ import __prog__, __version__
+from subtrs.__metadata__ import __prog__, __version__
 
 
 class Subtitles:
@@ -76,11 +76,11 @@ class Subtitles:
                 for line in self.f:
                     if line and not line[0].isdigit():
                         if len(line) > 1 and '--silent' not in self.flags:
-                            print(f'{self.IN_COLOR}<<{self.RESET_COLOR}'
-                                  f' {line}')
+                            print(f'[{self.detect_lang(line)}]{self.IN_COLOR}'
+                                  f' <<{self.RESET_COLOR} {line}')
                         line = self.translate(line, lang)
                         if len(line) > 1 and '--silent' not in self.flags:
-                            print(f'{self.OUT_COLOR}>> '
+                            print(f'[{lang}]{self.OUT_COLOR} >> '
                                   f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
                     new_subs.write(line)
             self.created_file(new_captions)
@@ -89,6 +89,10 @@ class Subtitles:
         '''Translate line per line'''
         return self.translator.translate(line, dest=lang).text + '\n'
 
+    def detect_lang(self, line):
+        '''Identifies the language used'''
+        return self.translator.detect(line).lang
+
     def created_file(self, file):
         '''Message when the file finished'''
         if self.file_exist(file):
